Index: inc/public/class.dc.template.php
===================================================================
--- inc/public/class.dc.template.php	(revision 2800)
+++ inc/public/class.dc.template.php	(revision 2832)
@@ -1787,5 +1787,5 @@
 	<!ELEMENT tpl:EntryCommentCount - O -- Number of comments for entry -->
 	<!ATTLIST tpl:EntryCommentCount
-	none		CDATA	#IMPLIED	-- text to display for "no comment" (default: no comment)
+	none		CDATA	#IMPLIED	-- text to display for "no comments" (default: no comments)
 	one		CDATA	#IMPLIED	-- text to display for "one comment" (default: one comment)
 	more		CDATA	#IMPLIED	-- text to display for "more comments" (default: %s comments, %s is replaced by the number of comment)
@@ -1816,5 +1816,5 @@
 	<!ELEMENT tpl:EntryPingCount - O -- Number of trackbacks for entry -->
 	<!ATTLIST tpl:EntryPingCount
-	none	CDATA	#IMPLIED	-- text to display for "no ping" (default: no ping)
+	none	CDATA	#IMPLIED	-- text to display for "no pings" (default: no pings)
 	one	CDATA	#IMPLIED	-- text to display for "one ping" (default: one ping)
 	more	CDATA	#IMPLIED	-- text to display for "more pings" (default: %s trackbacks, %s is replaced by the number of pings)
@@ -1826,5 +1826,5 @@
 			'$_ctx->posts->nb_trackback',
 			array(
-				'none' => 'no trackback',
+				'none' => 'no trackbacks',
 				'one'  => 'one trackback',
 				'more' => '%d trackbacks'
Index: locales/_pot/public.pot
===================================================================
--- locales/_pot/public.pot	(revision 0)
+++ locales/_pot/public.pot	(revision 2832)
@@ -41,5 +41,5 @@
 msgstr ""
 
-msgid "no comment"
+msgid "no comments"
 msgstr ""
 
@@ -50,5 +50,5 @@
 msgstr ""
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -59,5 +59,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
@@ -85,5 +85,5 @@
 msgid "Your search for <em>%1$s</em> returned no result."
 msgstr ""
-    
+
 msgid "Your search for <em>%1$s</em> returned <strong>%2$s</strong> result."
 msgstr ""
@@ -238,5 +238,5 @@
 msgid "You must provide a valid email address."
 msgstr ""
- 
+
 msgid "Read"
 msgstr ""
Index: locales/bn/public.po
===================================================================
--- locales/bn/public.po	(revision 2807)
+++ locales/bn/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "শূণ্য মন্তব্য"
 
@@ -52,5 +52,5 @@
 msgstr "%dটি মন্তব্য"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "শূণ্য ট্র্যাকব্যাক"
 
@@ -61,5 +61,5 @@
 msgstr "%dটি ট্র্যাকব্যাক"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "শূণ্য এটাচমেন্ট"
 
Index: locales/ca/public.po
===================================================================
--- locales/ca/public.po	(revision 2807)
+++ locales/ca/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "Sense comentaris"
 
@@ -51,5 +51,5 @@
 msgstr "%d comentaris"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "Sense respostes"
 
@@ -60,5 +60,5 @@
 msgstr "%d respostes"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "sense fitxers adjunts"
 
Index: locales/cs/public.po
===================================================================
--- locales/cs/public.po	(revision 2807)
+++ locales/cs/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "žádné komentáře"
 
@@ -53,5 +53,5 @@
 msgstr "%d komentářů(e)"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "žádné trackbacky"
 
@@ -62,5 +62,5 @@
 msgstr "%d trackbacků(y)"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "žádná příloha"
 
Index: locales/da/public.po
===================================================================
--- locales/da/public.po	(revision 2807)
+++ locales/da/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 msgstr ""
 
-msgid "no comment"
+msgid "no comments"
 msgstr ""
 
@@ -51,5 +51,5 @@
 msgstr ""
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -60,5 +60,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
Index: locales/de/public.po
===================================================================
--- locales/de/public.po	(revision 2807)
+++ locales/de/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "Kein Kommentar"
 
@@ -53,5 +53,5 @@
 msgstr "%d Kommentare"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "Kein Trackback"
 
@@ -62,5 +62,5 @@
 msgstr "%d Trackbacks"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "Keine Dateianlage"
 
Index: locales/en/public.po
===================================================================
--- locales/en/public.po	(revision 2807)
+++ locales/en/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 msgstr ""
 
-msgid "no comment"
+msgid "no comments"
 msgstr ""
 
@@ -52,5 +52,5 @@
 msgstr ""
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -61,5 +61,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
Index: locales/eo/public.po
===================================================================
--- locales/eo/public.po	(revision 2807)
+++ locales/eo/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "neniu komento"
 
@@ -52,5 +52,5 @@
 msgstr "%d komentoj"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "neniu retroligo"
 
@@ -61,5 +61,5 @@
 msgstr "%d retroligoj"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "neniu aldonaĵo"
 
Index: locales/es-ar/public.po
===================================================================
--- locales/es-ar/public.po	(revision 2807)
+++ locales/es-ar/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "sin comentarios"
 
@@ -52,5 +52,5 @@
 msgstr "%d comentarios"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "sin enlaces inversos"
 
@@ -61,5 +61,5 @@
 msgstr "%d enlaces inversos"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "sin archivos adjuntos"
 
Index: locales/es/public.po
===================================================================
--- locales/es/public.po	(revision 2807)
+++ locales/es/public.po	(revision 2832)
@@ -46,5 +46,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "sin comentarios"
 
@@ -55,5 +55,5 @@
 msgstr "%d comentarios"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "sin retroenlaces"
 
@@ -64,5 +64,5 @@
 msgstr "%d retroenlaces"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "sin adjuntos"
 
Index: locales/eu/public.po
===================================================================
--- locales/eu/public.po	(revision 2807)
+++ locales/eu/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "iruzkinik ez "
 
@@ -51,5 +51,5 @@
 msgstr "%d iruzkin "
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -60,5 +60,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "eranskinik ez"
 
Index: locales/fr/public.po
===================================================================
--- locales/fr/public.po	(revision 2806)
+++ locales/fr/public.po	(revision 2832)
@@ -41,5 +41,5 @@
 msgstr "Lire la suite"
 
-msgid "no comment"
+msgid "no comments"
 msgstr "aucun commentaire"
 
@@ -50,5 +50,5 @@
 msgstr "%d commentaires"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "aucun rétrolien"
 
@@ -59,5 +59,5 @@
 msgstr "%d rétroliens"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "aucune annexe"
 
Index: locales/hu/public.po
===================================================================
--- locales/hu/public.po	(revision 2807)
+++ locales/hu/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "nincs hozzászólás"
 
@@ -53,5 +53,5 @@
 msgstr "%d hozzászólás"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "nincs trackback"
 
@@ -62,5 +62,5 @@
 msgstr "%d trackback"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "nincs melléklet"
 
Index: locales/it/public.po
===================================================================
--- locales/it/public.po	(revision 2807)
+++ locales/it/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "nessuno commento"
 
@@ -52,5 +52,5 @@
 msgstr "%d commenti"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "nessun trackback"
 
@@ -61,5 +61,5 @@
 msgstr "%d trackback"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "nessun allegato"
 
Index: locales/ja/public.po
===================================================================
--- locales/ja/public.po	(revision 2807)
+++ locales/ja/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "コメント(0)"
 
@@ -53,5 +53,5 @@
 msgstr "コメント(%d)"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "トラックバック(0)"
 
@@ -62,5 +62,5 @@
 msgstr "トラックバック(%d)"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "添付(0)"
 
Index: locales/ko/public.po
===================================================================
--- locales/ko/public.po	(revision 221)
+++ locales/ko/public.po	(revision 2832)
@@ -41,5 +41,5 @@
 msgstr "본문으로"
 
-msgid "no comment"
+msgid "no comments"
 msgstr "댓글 없음"
 
@@ -50,5 +50,5 @@
 msgstr "댓글 %d 개"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "글걸이 없음"
 
@@ -59,5 +59,5 @@
 msgstr "글걸이 %d 개"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "첨부파일 없음"
 
Index: locales/lt/public.po
===================================================================
--- locales/lt/public.po	(revision 2807)
+++ locales/lt/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "komentarų nėra"
 
@@ -53,5 +53,5 @@
 msgstr "%d komentarai"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "trackback nėra"
 
@@ -62,5 +62,5 @@
 msgstr "%d trackback"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "prisegimų nėra"
 
Index: locales/nl/public.po
===================================================================
--- locales/nl/public.po	(revision 2807)
+++ locales/nl/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "geen comments"
 
@@ -53,5 +53,5 @@
 msgstr "%d comments"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "geen trackback"
 
@@ -62,5 +62,5 @@
 msgstr "%d trackbacks"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "geen bijlages"
 
Index: locales/oc/public.po
===================================================================
--- locales/oc/public.po	(revision 2807)
+++ locales/oc/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "0 comentaris"
 
@@ -51,5 +51,5 @@
 msgstr "%d comentaris"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -60,5 +60,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
Index: locales/pl/public.po
===================================================================
--- locales/pl/public.po	(revision 2807)
+++ locales/pl/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "brak komentarzy"
 
@@ -52,5 +52,5 @@
 msgstr "%d komentarzy"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "brak trackbacków"
 
@@ -61,5 +61,5 @@
 msgstr "%d trackbacków"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "brak załączników"
 
Index: locales/pt-br/public.po
===================================================================
--- locales/pt-br/public.po	(revision 2807)
+++ locales/pt-br/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "nenhum comentário"
 
@@ -52,5 +52,5 @@
 msgstr "%d comentários"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "nenhum trackback"
 
@@ -61,5 +61,5 @@
 msgstr "%d trackbacks"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "nenhum anexo"
 
Index: locales/pt/public.po
===================================================================
--- locales/pt/public.po	(revision 2807)
+++ locales/pt/public.po	(revision 2832)
@@ -45,5 +45,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "sem comentário"
 
@@ -54,5 +54,5 @@
 msgstr "%d comentários"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "sem trackback"
 
@@ -63,5 +63,5 @@
 msgstr "%d trackbacks"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "sem anexo"
 
Index: locales/ro/public.po
===================================================================
--- locales/ro/public.po	(revision 2807)
+++ locales/ro/public.po	(revision 2832)
@@ -44,5 +44,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "niciun comentariu"
 
@@ -53,5 +53,5 @@
 msgstr "%d comentarii"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "fără trackback"
 
@@ -62,5 +62,5 @@
 msgstr "%d trackback-uri"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "niciun atașament"
 
Index: locales/ru/public.po
===================================================================
--- locales/ru/public.po	(revision 2807)
+++ locales/ru/public.po	(revision 2832)
@@ -41,5 +41,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "нет комментариев"
 
@@ -50,5 +50,5 @@
 msgstr "Комментариев: %d"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "нет трекбеков"
 
@@ -59,5 +59,5 @@
 msgstr "Трекбеков: %d"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "нет вложений"
 
Index: locales/sr/public.po
===================================================================
--- locales/sr/public.po	(revision 2807)
+++ locales/sr/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 msgstr ""
 
-msgid "no comment"
+msgid "no comments"
 msgstr ""
 
@@ -51,5 +51,5 @@
 msgstr ""
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -60,5 +60,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
Index: locales/sv/public.po
===================================================================
--- locales/sv/public.po	(revision 2807)
+++ locales/sv/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 msgstr ""
 
-msgid "no comment"
+msgid "no comments"
 msgstr ""
 
@@ -51,5 +51,5 @@
 msgstr ""
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr ""
 
@@ -60,5 +60,5 @@
 msgstr ""
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr ""
 
Index: locales/te/public.po
===================================================================
--- locales/te/public.po	(revision 2807)
+++ locales/te/public.po	(revision 2832)
@@ -42,5 +42,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "వ్యాఖ్యలు లేవు"
 
@@ -51,5 +51,5 @@
 msgstr "%d వ్యాఖ్యలు"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "ట్రాకుబ్యాకులు లేవు"
 
@@ -60,5 +60,5 @@
 msgstr "%d ట్రాకుబ్యాకులు"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "జోడింపులు లేవు"
 
Index: locales/tr/public.po
===================================================================
--- locales/tr/public.po	(revision 2807)
+++ locales/tr/public.po	(revision 2832)
@@ -40,5 +40,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "ahkam yok"
 
@@ -49,5 +49,5 @@
 msgstr "%d ahkam"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "gerizleme yok"
 
@@ -58,5 +58,5 @@
 msgstr "%d gerizleme"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "ek yok"
 
Index: locales/zh-cn/public.po
===================================================================
--- locales/zh-cn/public.po	(revision 2807)
+++ locales/zh-cn/public.po	(revision 2832)
@@ -43,5 +43,5 @@
 
 #, fuzzy
-msgid "no comment"
+msgid "no comments"
 msgstr "没有评论"
 
@@ -52,5 +52,5 @@
 msgstr "%d 个评论"
 
-msgid "no trackback"
+msgid "no trackbacks"
 msgstr "没有 trackback"
 
@@ -61,5 +61,5 @@
 msgstr "%d 个 trackback"
 
-msgid "no attachment"
+msgid "no attachments"
 msgstr "没有附件"
 
Index: plugins/attachments/_public.php
===================================================================
--- plugins/attachments/_public.php	(revision 2646)
+++ plugins/attachments/_public.php	(revision 2832)
@@ -204,5 +204,5 @@
 	<!ELEMENT tpl:EntryAttachmentCount - O -- Number of attachments for entry -->
 	<!ATTLIST tpl:EntryAttachmentCount
-	none	CDATA	#IMPLIED	-- text to display for "no attachment" (default: no attachment)
+	none	CDATA	#IMPLIED	-- text to display for "no attachments" (default: no attachments)
 	one	CDATA	#IMPLIED	-- text to display for "one attachment" (default: one attachment)
 	more	CDATA	#IMPLIED	-- text to display for "more attachment" (default: %s attachment, %s is replaced by the number of attachments)
@@ -215,5 +215,5 @@
 			'$_ctx->posts->countMedia()',
 			array(
-				'none' => 'no attachment',
+				'none' => 'no attachments',
 				'one'  => 'one attachment',
 				'more' => '%d attachments'
